pub struct Completable<T> { /* private fields */ }Implementations
Sourceimpl<T> Completable<T>
impl<T> Completable<T>
pub fn new(val: T) -> Self
Sourcepub fn complete_exclusive(&self, f: impl FnOnce() -> T) -> bool
pub fn complete_exclusive(&self, f: impl FnOnce() -> T) -> bool
Completes this instance in exclusive mode, wherein the given closure is atomically invoked if and only if the instance is incomplete. No other thread may succeed in completing this instance in the meantime.
This method is used when f represents an expensive computation, the result of
which should not be discarded. Conversely, if this instance is already
complete, f should not be attempted.
Returns true if and only if f was invoked.
Sourcepub fn complete(&self, val: T) -> bool
pub fn complete(&self, val: T) -> bool
Completes this instance, assigning val if the instance is incomplete. Otherwise,
the existing completed value is preserved.
Returns true if and only if val was assigned.
pub fn is_complete(&self) -> bool
pub fn get(&self) -> Completed<'_, T>
pub fn peek<'a>(&'a self) -> impl Deref<Target = Option<T>> + 'a
pub fn try_get<'a>( &'a self, duration: Duration, ) -> impl Deref<Target = Option<T>> + 'a
pub fn into_inner(self) -> Option<T>